Detector class abstract

Abstract base class for image type detectors.

Defines the interface for detecting the type of an image file. Implement this class to create custom detection strategies.

Implementers

Constructors

Detector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(File filePath) ImageType
Detects the image type of the given file.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited